@@ -60,6 +60,7 @@ if DEBUNDLED:
     # Actually alias all of our vendored dependencies.
     vendored("appdirs")
     vendored("cachecontrol")
+    vendored("certifi")
     vendored("colorama")
     vendored("contextlib2")
     vendored("distlib")
@@ -75,7 +76,6 @@ if DEBUNDLED:
     vendored("pep517")
     vendored("pkg_resources")
     vendored("progress")
-    vendored("pytoml")
     vendored("retrying")
     vendored("requests")
     vendored("requests.exceptions")
@@ -107,4 +107,8 @@ if DEBUNDLED:
     vendored("requests.packages.urllib3.util.ssl_")
     vendored("requests.packages.urllib3.util.timeout")
     vendored("requests.packages.urllib3.util.url")
+    vendored("resolvelib")
+    vendored("toml")
+    vendored("toml.encoder")
+    vendored("toml.decoder")
     vendored("urllib3")
